import GeoIP
from nose.tools import assert_equal


def test_region():
    gi = GeoIP.open("tests/data/GeoIPRegion.dat", GeoIP.GEOIP_STANDARD)

    gir = gi.region_by_addr('64.17.254.223')

    region = {
        'region': 'CA',
        'region_name': 'California',
        'country_code': 'US'
    }
    assert_equal(gir, region)



#!/usr/bin/python

from __future__ import print_function

import GeoIP

gi = GeoIP.open("/usr/local/share/GeoIP/GeoIPOrg.dat", GeoIP.GEOIP_STANDARD)

print(gi.org_by_name("yahoo.com"))
print(gi.org_by_name("www.google.com"))
print(gi.org_by_addr("24.24.24.24"))



import GeoIP
from nose.tools import assert_equal


def test_errors():
    # The intent of these tests is to make sure there are no segfaults.
    # Most of the lookups are invalid. Unfortunately the API rarely throws
    # exceptions.
    gi = GeoIP.open("tests/data/GeoIP.dat", GeoIP.GEOIP_STANDARD)

    assert_equal(gi.org_by_addr('1.1.1.1'), None)

    assert_equal(gi.country_code_by_name('1.1.1.1'), None)

    assert_equal(gi.country_name_by_name('1.1.1.1'), None)

    assert_equal(gi.country_code_by_addr('1.1.1.1'), None)

    assert_equal(gi.country_name_by_addr('1.1.1.1'), None)

    assert_equal(gi.name_by_addr('1.1.1.1'), None)

    assert_equal(gi.name_by_name('1.1.1.1'), None)

    assert_equal(gi.org_by_addr('1.1.1.1'), None)

    assert_equal(gi.org_by_name('1.1.1.1'), None)

    assert_equal(gi.region_by_addr('1.1.1.1'), None)

    assert_equal(gi.region_by_name('1.1.1.1'), None)
    assert_equal(gi.record_by_addr('1.1.1.1'), None)

    assert_equal(gi.record_by_name('1.1.1.1'), None)

    assert_equal(gi.range_by_ip('1.1.1.1'), ('0.0.0.0', '12.87.117.255'))

    assert_equal(gi.last_netmask(), 5)

    assert_equal(gi.country_code_by_name_v6('1.1.1.1'), None)

    assert_equal(gi.country_name_by_name_v6('1.1.1.1'), None)

    assert_equal(gi.country_code_by_addr_v6('1.1.1.1'), None)

    assert_equal(gi.country_name_by_addr_v6('1.1.1.1'), None)

    assert_equal(gi.enable_teredo(-100), 1)
    assert_equal(gi.teredo(), 0)
    assert_equal(gi.id_by_addr('1.1.1.1'), 0)
    assert_equal(gi.id_by_name('1.1.1.1'), 0)
    assert_equal(gi.record_by_addr_v6('1.1.1.1'), None)

    assert_equal(gi.record_by_name_v6('1.1.1.1'), None)



#!/usr/bin/python

from __future__ import print_function

import GeoIP

#gi = GeoIP.new(GeoIP.GEOIP_STANDARD)
#gi = GeoIP.new(GeoIP.GEOIP_MMAP_CACHE)
gi = GeoIP.new(GeoIP.GEOIP_MEMORY_CACHE)
#gi = GeoIP.open("/usr/local/share/GeoIP/GeoIP.dat",GeoIP.GEOIP_STANDARD)

print(gi.country_code_by_name("yahoo.com"))
print(gi.last_netmask())
print(gi.country_name_by_name("www.bundestag.de"))
print(gi.country_code_by_addr("24.24.24.24"))
print(gi.country_name_by_addr("24.24.24.24"))
print(gi.range_by_ip("68.180.206.184"))



#!/usr/bin/python

from __future__ import print_function

import GeoIP

gi = GeoIP.open("/usr/local/share/GeoIP/GeoIPCity.dat", GeoIP.GEOIP_STANDARD)

gir = gi.record_by_name("www.google.com")
#gir = gi.record_by_addr("24.24.24.24")

if gir is not None:
    print(gir['country_code'])
    print(gir['country_code3'])
    print(gir['country_name'])
    print(gir['city'])
    print(gir['region'])
    print(gir['region_name'])
    print(gir['postal_code'])
    print(gir['latitude'])
    print(gir['longitude'])
    print(gir['area_code'])
    print(gir['time_zone'])
    print(gir['metro_code'])
    print(str(gir))



import GeoIP
from nose.tools import assert_equal


def test_city():
    gi = GeoIP.open("tests/data/GeoIPCity.dat", GeoIP.GEOIP_STANDARD)

    gir = gi.record_by_addr("64.17.254.216")

    record = {
        'area_code': 310,
        'city': 'El Segundo',
        'country_code': 'US',
        'country_code3': 'USA',
        'country_name': 'United States',
        'dma_code': 803,
        'latitude': 33.91640090942383,
        'longitude': -118.40399932861328,
        'metro_code': 803,
        'postal_code': '90245',
        'region': 'CA',
        'region_name': 'California',
        'time_zone': 'America/Los_Angeles'
    }

    assert_equal(gir, record)


def test_non_ascii_city():
    gi = GeoIP.open("tests/data/GeoIPCity.dat", GeoIP.GEOIP_STANDARD)

    gir = gi.record_by_addr("89.92.212.80")

    record = {
        'city': 'F\xe2ches-thumesnil',
        'region_name': 'Nord-Pas-de-Calais',
        'region': 'B4', 'area_code': 0,
        'time_zone': 'Europe/Paris',
        'longitude': 3.0808000564575195,
        'metro_code': 0,
        'country_code3': 'FRA',
        'latitude': 50.5906982421875,
        'postal_code': None,
        'dma_code': 0,
        'country_code': 'FR',
        'country_name': 'France'
    }

    assert_equal(gir, record)



#!/usr/bin/python

from __future__ import print_function

import GeoIP

gi = GeoIP.open(
    "/usr/local/share/GeoIP/GeoIPNetspeed.dat", GeoIP.GEOIP_STANDARD)

# GEOIP_UNKNOWN_SPEED, GEOIP_DIALUP_SPEED, GEOIP_CABLEDSL_SPEED or
# GEOIP_CORPORATE_SPEED

print(gi.id_by_name("yahoo.com"))
print(gi.id_by_name("www.maxmind.com") == GeoIP.GEOIP_UNKNOWN_SPEED)
print(gi.id_by_addr("203.195.93.0"))



import GeoIP
from nose.tools import assert_equal


def test_org():
    gi = GeoIP.open("tests/data/GeoIPOrg.dat", GeoIP.GEOIP_STANDARD)

    assert_equal(gi.org_by_addr("12.87.118.0"), 'AT&T Worldnet Services')



import GeoIP
from nose.tools import assert_equal


def test_ipv6():
    gi = GeoIP.open("tests/data/GeoIPv6.dat", GeoIP.GEOIP_STANDARD)

    assert_equal(gi.country_code_by_addr_v6('2001:200::'), 'JP')



# -*- coding: utf-8 -*-

import GeoIP
from nose.tools import assert_equal


def test_charset():
    gi = GeoIP.open("tests/data/GeoIPOrg.dat", GeoIP.GEOIP_STANDARD)

    gi.set_charset(GeoIP.GEOIP_CHARSET_UTF8)
    assert_equal(gi.charset(), GeoIP.GEOIP_CHARSET_UTF8)

    assert_equal(gi.name_by_addr("142.217.214.0"),
                 'LINO Solutions Internet de Télébec')



import GeoIP
from nose.tools import assert_equal


def test_netspeed_cell():
    gi = GeoIP.open("tests/data/GeoIPNetSpeedCell.dat", GeoIP.GEOIP_STANDARD)

    assert_equal(gi.org_by_addr("2.125.160.1"), 'Dialup')



import GeoIP
from nose.tools import assert_equal


def test_domain():
    gi = GeoIP.open("tests/data/GeoIPDomain.dat", GeoIP.GEOIP_STANDARD)

    assert_equal(gi.org_by_addr("67.43.156.0"), 'shoesfin.NET')



import sys

try:
    from setuptools import setup, Extension
except ImportError:
    from distutils.core import setup, Extension

libs = ['GeoIP']

if sys.platform == 'win32':
    libs.append('ws2_32')

compile_args = []
# http://bugs.python.org/issue969718
if sys.version_info[0] == 2:
    compile_args.append('-fno-strict-aliasing')

module1 = Extension('GeoIP',
                    libraries=libs,
                    sources=['py_GeoIP.c'],
                    extra_compile_args=compile_args)

setup(
    name='GeoIP',
    version='1.3.2',
    description='MaxMind GeoIP Legacy Database - Python API',
    long_description=open('README.rst').read(),
    author="MaxMind, Inc.",
    author_email="support@maxmind.com",
    url='http://www.maxmind.com/',
    bugtrack_url='https://github.com/maxmind/geoip-api-python/issues',
    license=open('LICENSE').read(),
    ext_modules=[module1],
    tests_require=['nose'],
    test_suite='nose.collector',
    classifiers=(
        'Development Status :: 6 - Mature',
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'Intended Audience :: System Administrators',
        'License :: OSI Approved :: GNU Lesser General Public License v2 or later (LGPLv2+)',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python',
        'Topic :: Internet :: Proxy Servers',
        'Topic :: Internet',
    ),
)



#!/usr/bin/python

from __future__ import print_function

import GeoIP

#gi = GeoIP.new(GeoIP.GEOIP_STANDARD)
#gi = GeoIP.new(GeoIP.GEOIP_MEMORY_CACHE)
gi = GeoIP.open("/usr/local/share/GeoIP/GeoIPv6.dat", GeoIP.GEOIP_STANDARD)

print(gi.country_code_by_name_v6("ipv6.google.com"))
print(gi.country_name_by_name_v6("ipv6.google.com"))
print(gi.country_code_by_addr_v6("2001:4860:0:1001::68"))
print(gi.country_name_by_addr_v6("2001:4860:0:1001::68"))



import GeoIP
from nose.tools import assert_equal


def test_country():
    for mode in [GeoIP.GEOIP_STANDARD, GeoIP.GEOIP_MEMORY_CACHE,
                 GeoIP.GEOIP_MMAP_CACHE, GeoIP.GEOIP_INDEX_CACHE]:
        gi = GeoIP.open("tests/data/GeoIP.dat", GeoIP.GEOIP_STANDARD)

        assert_equal(gi.country_code_by_addr('64.17.254.216'), 'US')
        assert_equal(gi.last_netmask(), 29)
        assert_equal(
            gi.country_name_by_addr('64.17.254.216'), 'United States')
        assert_equal(gi.range_by_ip('64.17.254.216'),
                      ('64.17.254.216', '64.17.254.223'))



#!/usr/bin/python

import GeoIP

# open the citydatabase. All cities return in iso-8859-1 by default
gi = GeoIP.open("/usr/local/share/GeoIP/GeoIPCity.dat", GeoIP.GEOIP_STANDARD)

# lookup a record, where cityname contains chars > 127 ( eg != ascii )
gir = gi.record_by_name("www.osnabrueck.de")

# print(the cityname with iso-8859-1 charset)
print(gir)

# however, at your option GeoIP can return the cityname in utf8
# just put GeoIP into utf8 mode
#
# from now on all records returns in UTF8 until you change the charset again
# Notice, that all previous records return in the previous charset
gi.set_charset(GeoIP.GEOIP_CHARSET_UTF8)

# get a new record, now in utf8
gir2 = gi.record_by_name("www.osnabrueck.de")

# and print(it ( should be the same output as on line 2 ))
print(gir2)

# Some more charset examples
# current_charset = gi.charset()
# old_charset = gi.set_charset(GeoIP.GEOIP_CHARSET_ISO_8859_1);



#!/usr/bin/python

# This example is only for Python 2. In Python 3, all returned strings are
# unicode.
import GeoIP

# open the citydatabase. All cities return in iso-8859-1 by default
gi = GeoIP.open("/usr/local/share/GeoIP/GeoIPCity.dat", GeoIP.GEOIP_STANDARD)

# lookup a record, where cityname contains chars > 127 ( eg != ascii )
gir = gi.record_by_name("www.osnabrueck.de")

# print the cityname with iso-8859-1 charset
print gir['city']

# print the cityname transformed to utf8
print unicode(gir['city'], 'iso-8859-1')

# however, at your option GeoIP can return the cityname in utf8
# just put GeoIP into utf8 mode
#
# from now on all records returns in UTF8 until you change the charset again
# Notice, that all previous records return in the previous charset
gi.set_charset(GeoIP.GEOIP_CHARSET_UTF8)

# get a new record, now in utf8
gir2 = gi.record_by_name("www.osnabrueck.de")

# and print it ( should be the same output as on line 2 )
print gir2['city']

# Some more charset examples
# current_charset = gi.charset()
# old_charset = gi.set_charset(GeoIP.GEOIP_CHARSET_ISO_8859_1);



#!/usr/bin/python

from __future__ import print_function

import GeoIP

gi = GeoIP.open("/usr/local/share/GeoIP/GeoIPRegion.dat", GeoIP.GEOIP_STANDARD)

gir = gi.region_by_name("www.google.com")
if gir is not None:
            print(gir['country_code'])

            print(gir['region'])
            print(gir['region_name'])
gir = gi.region_by_addr("24.24.24.24")
if gir is not None:
            print(gir['country_code'])
            print(gir['region'])
            print(gir['region_name'])
